@@ -1,12 +1,14 @@
 #! /bin/sh
 # \
-exec wish8.2 "$0" "$@"
+exec wish "$0" "$@"
+
+package require Tk 8.4
 
 #################################################################
 # ntkinfo.tcl - a slimmed down and updated tkinfo
 # (http://math-www.uni-paderborn.de/~axel/tkinfo)
 # 
-# Copyright (C) 1999 Mark Patton
+# Copyright (C) 1999-2002 Mark Patton
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,7 +25,7 @@ exec wish8.2 "$0" "$@"
 # Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 ###################################################################
 
-# To use as a lib, set the global var ntki_embed to a value.
+# To use as a lib, set the global var ntki_embed to a value and then source.
 # Interface:
 # ntki::init sets up ntkinfo.
 # ntki::win ?node? pops up a new toplevel and returns it.
@@ -57,7 +59,7 @@ proc ntki::init {} {
 	}
     } 
     lappend path /usr/info /usr/local/info /usr/gnu/info \
-	    /usr/local/gnu/info [pwd]
+	    /usr/local/gnu/info /usr/share/info /usr/local/share/info [pwd]
 
     set ntki(info_path) [list]
     set ntki(dirs) [list]
@@ -277,7 +279,7 @@ proc ntki::win {{node ""}} {
     frame $w.main
     pack [scrollbar $w.main.scroll -orient vertical \
 	    -command [list $w.main.text yview]] -side right -fill y
-    pack [text $w.main.text -wrap word -state disabled \
+    pack [text $w.main.text -font {Courier 12} -wrap word -state disabled \
 	    -yscroll [list $w.main.scroll set]] -side right -expand 1\
 	    -fill both
 
@@ -289,12 +291,11 @@ proc ntki::win {{node ""}} {
     entry $w.status.input
     bindtags $w.status.input [concat prompt [bindtags $w.status.input]]
 
-    set color [option get . linkColor ""]
-    set title_font [option get . titleFont ""]
+    set color blue
 
     $w.main.text tag configure xref -foreground $color
     $w.main.text tag configure menu -foreground $color
-    $w.main.text tag configure title -font $title_font
+    $w.main.text tag configure title -font {Courier 14 bold} -justify center
     
     $w.main.text tag bind xref <Enter> [list %W configure -cursor hand2]
     $w.main.text tag bind xref <Leave> [list %W configure -cursor left_ptr]
@@ -980,9 +981,6 @@ proc ntki::search_continue {w} {
 if {![info exists ntki_embed]} {
     source ./misc.tcl
     wm withdraw .
-    option add *linkColor blue
-    option add *titleFont {Courier 14 bold}
-    option add *Ntkinfo*Text*font {Courier 12}
 
     ntki::init
     if {[llength $argv]} {
