@@ -1,12 +1,12 @@
 array set config {
 lib_dir .
-version {1.4.1}
+version {1.5.1}
 }
 
 proc init {} {
-    global argv argv0 config env
+    global auto_path argv argv0 config env
     
-    package require Tcl 8.2
+    package require Tcl 8.4
 
     foreach opt $argv {
 	switch -exact -- $opt {
@@ -14,10 +14,11 @@ proc init {} {
 		puts "Usage: $argv0 \[INTERFACE\] OPTION..."
 		puts ""
 		puts "Interfaces:"
-		puts "tk      - GUI  (requires Tk)"
-		puts "xterm   - GUI  (requires Tk)"
-		puts "console - text (requires ANSI terminal)"
-		puts "text    - text (ANSI terminal not required)"
+		puts "tk       - GUI  (requires Tk)"
+		puts "gnome    - GUI  (requires tcl-gtk and Gnome)"
+		puts "console  - text (requires ANSI terminal and unix)"
+		puts "readline - text (requires tclreadline)"
+		puts "text     - text (works on any terminal)"
 		puts ""
 		puts "INTERFACE defaults to tk."
 		puts ""
@@ -26,6 +27,9 @@ proc init {} {
 		puts "-v --version       print the version and exit"
 		puts "-e --eval SCRIPT   start mmucl and eval SCRIPT"
 		puts ""
+		puts "Enviroment variable TCLLIBPATH can be used to specify"
+		puts "where Mmucl looks for Tcl extensions."
+		puts ""
 		puts "Report bugs to msp@users.sourceforge.net."
 		
 		exit 0
@@ -36,7 +40,7 @@ proc init {} {
 	}
     }
     
-    set interfaces [list tk xterm console text gtk]
+    set interfaces [list tk readline console text gnome]
     set interface [string tolower [lindex $argv 0]]
     
     if {[string match -* $interface] || [string equal $interface ""]} {
@@ -46,22 +50,28 @@ proc init {} {
     }
 
     if {[lsearch -exact $interfaces $interface] == -1} {
-	puts stderr "bad interface: $interface"
+	puts stderr "no such interface: $interface"
 	puts stderr "for more info: $argv0 --help"
 	exit 1
     }
 
     if {[info exists env(HOME)]} {
-	set config(rc_dir) [file join $env(HOME) .mmucl]
+	set config(rc_dir) [file join $env(HOME) .mmucl2]
     } else {
-	set config(rc_dir) [file join [pwd] .mmucl]
+	set config(rc_dir) [file join [pwd] .mmucl2]
+    }
+
+    foreach path {/usr/lib /usr/local/lib} {
+        if {[lsearch $auto_path $path] == -1} {
+            lappend auto_path $path
+        }
     }
 
     set config(interface) $interface
-    source [file join $config(lib_dir) lib mmucl.tcl]
-    source [file join $config(lib_dir) interface $interface.tcl]
+    uplevel #0 [list source [file join $config(lib_dir) lib mmucl.tcl]]
+    uplevel #0 [list source [file join $config(lib_dir) \
+	interface $interface.tcl]]
 
-    mmucl::interface_init
     mmucl::init
 
     rename init ""
